SmkitUiFlutterPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SmkitUiFlutterPluginPlatform
Implementers

Constructors

SmkitUiFlutterPluginPlatform()
Constructs a SmkitUiFlutterPluginPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAdaptiveRomCache() Future<void>
configure({required String key, SmKitPoseModelChoice poseModelChoice = SmKitPoseModelChoice.adaptiveChoice, SMKitLanguage configureLanguage = SMKitLanguage.english, bool includesHighlights = false, void onHandle(SMKitStatus)?}) Future<bool?>
getExerciseType({required String detector}) Future<String?>
getSupportedMovements() Future<List<String>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseSdk() Future<void>
quitWorkout() Future<void>
resumeSdk() Future<void>
setConfig({required SMKitConfig config}) Future<void>
setCounterPreferences({required SMKitCounterPreferences counterPreferences, void onHandle(SMKitStatus)?}) Future<void>
setEndExercisePreferences({required SMKitEndExercisePreferences endExercisePrefernces, void onHandle(SMKitStatus)?}) Future<void>
setExcludedFeedbacks({required List<String> feedbacks}) Future<void>
setFeedbacksUiToExclude({required List<String> feedbacks}) Future<void>
setLanguage({required SMKitLanguage language, void onHandle(SMKitStatus)?}) Future<void>
setPhoneCalibrationLanguage({required SMKitLanguage language}) Future<void>
startAssessment({required AssessmentTypes type, String? assessmentID, Map<String, dynamic>? userData, bool showSummary = false, bool forceShowUserDataScreen = false, Map<String, dynamic>? modifications, void onHandle(SMKitStatus)?}) Future<void>
startCustomizedAssessment({required SMKitWorkout assessment, Map<String, dynamic>? userData, bool forceShowUserDataScreen = false, bool showSummary = false, Map<String, dynamic>? modifications, void onHandle(SMKitStatus)?}) Future<void>
startCustomizedWorkout({required SMKitWorkout workout, bool showSummary = false, Map<String, dynamic>? userData, Map<String, dynamic>? modifications, void onHandle(SMKitStatus)?}) Future<void>
startWorkoutProgram({required WorkoutConfig config, Map<String, dynamic>? modifications, void onHandle(SMKitStatus)?}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SmkitUiFlutterPluginPlatform
The default instance of SmkitUiFlutterPluginPlatform to use.
getter/setter pair