SMKitExercise class

Constructors

SMKitExercise({String? detector, String? prettyName, int? totalSeconds, String? videoInstruction, String? exerciseIntro, List<SMKitUIElement>? uiElements, String? exerciseClosure, String? closureFailedSound, String? summaryTitle, String? summarySubTitle, String? summaryMainMetricTitle, String? summaryMainMetricSubTitle, String? side, bool? shortIntro, SMKitQuickMotionParams? quickMotionParams, SMKitRowingFeedbackLevel? rowingFeedbackLevel, SMKitPhonePosition? phonePosition, bool? guidanceMode, bool? useWideAngleCamera, bool? playPreExerciseCountdown, bool? playRepMilestoneVoice, int? repMilestoneInterval, bool? playSoundOnEachRep, bool? adaptiveRomFeedbackEnabled, int? adaptiveRomWarmupReps, Map<String, SMKitGuidanceVideoSegment>? guidanceVideoSegments, SMKitStretchSetConfig? stretchSetConfig, ScoringParams? scoringParams})

Properties

adaptiveRomFeedbackEnabled bool?
getter/setter pair
adaptiveRomWarmupReps int?
getter/setter pair
closureFailedSound String?
getter/setter pair
detector String?
getter/setter pair
exerciseClosure String?
getter/setter pair
exerciseIntro String?
getter/setter pair
guidanceMode bool?
getter/setter pair
guidanceVideoSegments Map<String, SMKitGuidanceVideoSegment>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
phonePosition SMKitPhonePosition?
getter/setter pair
playPreExerciseCountdown bool?
getter/setter pair
playRepMilestoneVoice bool?
getter/setter pair
playSoundOnEachRep bool?
getter/setter pair
prettyName String?
getter/setter pair
quickMotionParams SMKitQuickMotionParams?
getter/setter pair
repMilestoneInterval int?
getter/setter pair
rowingFeedbackLevel SMKitRowingFeedbackLevel?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scoringParams ScoringParams?
getter/setter pair
shortIntro bool?
getter/setter pair
side String?
getter/setter pair
stretchSetConfig SMKitStretchSetConfig?
getter/setter pair
summaryMainMetricSubTitle String?
getter/setter pair
summaryMainMetricTitle String?
getter/setter pair
summarySubTitle String?
getter/setter pair
summaryTitle String?
getter/setter pair
totalSeconds int?
getter/setter pair
uiElements List<SMKitUIElement>?
getter/setter pair
useWideAngleCamera bool?
getter/setter pair
videoInstruction String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited