SMKitGuidanceVideoSegment class

Constructors

SMKitGuidanceVideoSegment({required SMKitGuidanceVideoSegmentKind kind, required double startSeconds, double? endSeconds})
const
SMKitGuidanceVideoSegment.freeze(double seconds)
const
SMKitGuidanceVideoSegment.play({required double from, double? to})
const

Properties

endSeconds double?
final
hashCode int
The hash code for this object.
no setterinherited
kind SMKitGuidanceVideoSegmentKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startSeconds double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited