SMKitQuickMotionParams class

Constructors

SMKitQuickMotionParams({double validityWindow = 0.75, double checkInterval = 0.25})
const

Properties

checkInterval double
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validityWindow double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited