SMKitStretchSetConfig class

Constructors

SMKitStretchSetConfig({bool enabled = true, int repetitions = 1, int secondsPerStretch = 0, int restSecondsBetweenStretches = 3, String? introSoundKey, List<String>? positionDetectors})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
introSoundKey String?
final
positionDetectors List<String>?
final
repetitions int
final
restSecondsBetweenStretches int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondsPerStretch int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited