SMKitWorkoutContinuation class

Constructors

SMKitWorkoutContinuation({String? introSoundKey, required String interactionUnlockSoundKey, required List<SMKitExercise> exercises})
const

Properties

exercises List<SMKitExercise>
final
hashCode int
The hash code for this object.
no setterinherited
interactionUnlockSoundKey String
final
introSoundKey String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited