InstructionVideoConfig class

Config for instruction video (e.g. VideoInstructionCycle medium 2).

Constructors

InstructionVideoConfig({InstructionVideoDisplayMode displayMode = InstructionVideoDisplayMode.mediumCycle, int mediumSizeCycles = 2})
const

Properties

displayMode InstructionVideoDisplayMode
final
hashCode int
The hash code for this object.
no setterinherited
mediumSizeCycles int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited