SkeletonConfig class
Constructors
- SkeletonConfig({SkeletonPreset? preset, SkeletonConnectionStyle? connectionStyle, SkeletonJointShape? jointShape, double? dotsOpacity, double? connectionsOpacity, SkeletonColorOption? dotsInnerColor, SkeletonColorOption? dotsOuterColor, SkeletonColorOption? connectionsInnerColor, SkeletonColorOption? connectionsOuterColor, double? dotsGlow, double? connectionsGlow, double? lineWidthScale, double? outlineScale, double? softness, double? animationDuration})
-
const
Properties
- animationDuration → double?
-
final
- connectionsGlow → double?
-
final
- connectionsInnerColor → SkeletonColorOption?
-
final
- connectionsOpacity → double?
-
final
- connectionsOuterColor → SkeletonColorOption?
-
final
- connectionStyle → SkeletonConnectionStyle?
-
final
- dotsGlow → double?
-
final
- dotsInnerColor → SkeletonColorOption?
-
final
- dotsOpacity → double?
-
final
- dotsOuterColor → SkeletonColorOption?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- jointShape → SkeletonJointShape?
-
final
- lineWidthScale → double?
-
final
- outlineScale → double?
-
final
- preset → SkeletonPreset?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softness → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited