SmKitPoseModelChoice enum
Developer-selectable pose model strategy for Android SMKitUI 1.6.1+.
iOS currently accepts this value for API parity but ignores it.
- Inheritance
- Available extensions
Values
- adaptiveChoice → const SmKitPoseModelChoice
- prime → const SmKitPoseModelChoice
- pro → const SmKitPoseModelChoice
- lite → const SmKitPoseModelChoice
- ultraLite → const SmKitPoseModelChoice
- basic → const SmKitPoseModelChoice
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - nativeValue → String
-
Available on SmKitPoseModelChoice, provided by the SmKitPoseModelChoiceSerialization extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SmKitPoseModelChoice> - A constant List of the values in this enum, in order of their declaration.