SMKitScoringParams class

Constructors

SMKitScoringParams({required String? type, required num? targetTime, required num? targetReps, required List<String>? passCriteria, required String? targetRom, required double? scoringFactor})
SMKitScoringParams.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
passCriteria List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scoringFactor double?
getter/setter pair
targetReps num?
getter/setter pair
targetRom String?
getter/setter pair
targetTime num?
getter/setter pair
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited