SMKitConfig class
Constructors
-
SMKitConfig({bool? enableIntelligenceRest, bool? enableHeartRateRest, int? heartRateRestThreshold, bool? allowAudioMixing, bool? showExternalAudioControl, bool? playPhoneCalibrationAudio, bool? playBodyCalibrationAudio, bool? enableButtonTutorial, String? buttonTutorialCompletionAudioPath, bool? showRowingPhoneCalibration, bool? enableWatchCompanion, bool? accuratePoseEstimation, bool? enablePhoneMovementCountPrevention, bool? enableVariationMismatchFeedback, bool? startTimerOnFirstActivity, int? workoutContinuationTimerDuration, SkeletonConfig? skeletonConfig, SMKitColorTheme? colorTheme, List<
SMKitPauseType> ? pauseTypes, InstructionVideoConfig? instructionVideoConfig, bool? useDefaultGuidanceMode, bool? guidanceDebugLogging, String? androidConfigString, bool? showDebugBoundingBox}) -
const
Properties
- accuratePoseEstimation → bool?
-
final
- allowAudioMixing → bool?
-
final
- androidConfigString → String?
-
final
-
final
- colorTheme → SMKitColorTheme?
-
final
- enableButtonTutorial → bool?
-
final
- enableHeartRateRest → bool?
-
final
- enableIntelligenceRest → bool?
-
final
- enablePhoneMovementCountPrevention → bool?
-
final
- enableVariationMismatchFeedback → bool?
-
final
- enableWatchCompanion → bool?
-
final
- guidanceDebugLogging → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartRateRestThreshold → int?
-
final
- instructionVideoConfig → InstructionVideoConfig?
-
final
-
pauseTypes
→ List<
SMKitPauseType> ? -
final
- playBodyCalibrationAudio → bool?
-
final
- playPhoneCalibrationAudio → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDebugBoundingBox → bool?
-
final
- showExternalAudioControl → bool?
-
final
- showRowingPhoneCalibration → bool?
-
final
- skeletonConfig → SkeletonConfig?
-
final
- startTimerOnFirstActivity → bool?
-
final
- useDefaultGuidanceMode → bool?
-
final
- workoutContinuationTimerDuration → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited