SMKitConfig class

Constructors

SMKitConfig({bool? enableIntelligenceRest, bool? allowAudioMixing, bool? showExternalAudioControl, bool? showRowingPhoneCalibration, bool? enableWatchCompanion, bool? enableHeartRateRest, int? heartRateRestThreshold, bool? accuratePoseEstimation, SkeletonConfig? skeletonConfig, List<SMKitPauseType>? pauseTypes})
const

Properties

accuratePoseEstimation bool?
final
allowAudioMixing bool?
final
enableHeartRateRest bool?
final
enableIntelligenceRest bool?
final
enableWatchCompanion bool?
final
hashCode int
The hash code for this object.
no setterinherited
heartRateRestThreshold int?
final
pauseTypes List<SMKitPauseType>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showExternalAudioControl bool?
final
showRowingPhoneCalibration bool?
final
skeletonConfig SkeletonConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited