SkeletonPreset enum
Values
- defaultPreset → const SkeletonPreset
- minimalDots → const SkeletonPreset
- thinOutline → const SkeletonPreset
- monochromeClean → const SkeletonPreset
- neonGlow → const SkeletonPreset
- boldHighlight → const SkeletonPreset
- softFill → const SkeletonPreset
- wireframe → const SkeletonPreset
- highContrast → const SkeletonPreset
- pastel → const SkeletonPreset
- darkOutline → const SkeletonPreset
- minimalLine → const SkeletonPreset
- doubleStroke → const SkeletonPreset
- gradientReady → const SkeletonPreset
- subtleShadow → const SkeletonPreset
- classic → const SkeletonPreset
- athletic → const SkeletonPreset
- hologram → const SkeletonPreset
- matte → const SkeletonPreset
- neonPulse → const SkeletonPreset
- outlineOnly → const SkeletonPreset
- slim → const SkeletonPreset
- thick → const SkeletonPreset
- studio → const SkeletonPreset
- accessibility → const SkeletonPreset
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SkeletonPreset> - A constant List of the values in this enum, in order of their declaration.